@@ -1,5 +1,5 @@
 /*
-Copyright (C) 1997-2005 Erwin Waterlander
+Copyright (C) 1997-2015 Erwin Waterlander
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -33,26 +33,38 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #  endif
 #endif
 
+#if (defined(WCD_ANSI) || defined(WCD_UTF16))
+#include <wchar.h>
+#endif
+#include "std_macr.h"
+#include "structur.h"
+
+#ifdef WCD_ANSI
 size_t wcstoansi(char *mbstr, const wchar_t *wcstr, int len);
 size_t ansitowcs(wchar_t *wcstr, const char *mbstr, int len);
+#endif
+#ifdef WCD_UTF16
 size_t wcstoutf8(char *mbstr, const wchar_t *wcstr, int len);
 size_t utf8towcs(wchar_t *wcstr, const char *mbstr, int len);
+#endif
 void wcd_printf( const char* format, ... );
-void wcd_wprintf( const wchar_t* format, ... );
+#if (defined(WCD_USECONIO) || defined(WCD_USECURSES))
 size_t str_columns (char *s);
+#endif
 void sort_list(nameset list);
 int display_list(nameset list,int perfect, int use_numbers, int use_stdout);
+#ifdef WCD_USECONIO
 int display_list_conio(nameset list,WcdStack ws, int perfect,int use_numbers);
+#endif
+#ifdef WCD_USECURSES
 int display_list_curses(nameset list, WcdStack ws, int perfect,int use_numbers);
+void wcd_mvwaddstr(WINDOW *win, int x, int y, char *str);
+#endif
 int display_list_stdout(nameset list,WcdStack ws, int perfect, int use_stdout);
 
 #define OFFSET 39
 #define WCD_MAX_INPSTR 256
 
-#ifdef WCD_USECURSES
-void wcd_mvwaddstr(WINDOW *win, int x, int y, char *str);
-#  define INPUT_WIN_LEN 80
-#endif
 #define PAGEOFFSET 38
 
 #define SCROLL_WIN_HEIGHT 22
@@ -65,4 +77,15 @@ void wcd_mvwaddstr(WINDOW *win, int x, int y, char *str);
 #define WCD_STDOUT_NORMAL 1 /* stdout mode */
 #define WCD_STDOUT_DUMP   2 /* dump to stdout */
 
+#if defined(_WIN32) && !defined(__CYGWIN__) /* Windows, not Cygwin */
+/* On Windows we use wclear, because wclear gives a cleaner screen in a Windows
+ * Command Prompt in an East Asian locale with double width font. E.g. Chinese
+ * locale CP936 with raster or Simsun font. wclear gives some screen
+ * flickering when used with ncurses on Windows. */
+#define WCD_WCLEAR wclear
+#else
+/* We prefer werase, because it gives a steadier screen. Less flickering. */
+#define WCD_WCLEAR werase
+#endif
+
 #endif
